/*
  Bear Engine

  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file string.hpp
 * \brief Various types to use for strings and unicode.
 * \author Julien Jorge
 */
#ifndef __CHARSET_DEF_HPP__
#define __CHARSET_DEF_HPP__

#include <string>

namespace bear
{
  namespace charset
  {
    /** \brief Unicode character type. */
    typedef wchar_t char_type;

    /** \brief Unicode string. */
    typedef std::string string_type;

  } // namespace charset
} // namespace bear

#endif // __CHARSET_DEF_HPP__
